# socketio_app
A quick example of how to use ellar Websocket Gateway with python-socketio library.

## Requirements
Python >= 3.8
Poetry

## Project setup
```
poetry install
```

### Development Server
```
ellar runserver --reload
```

### Page
visit [http://127.0.0.1:8000/events/](http://127.0.0.1:8000/events/)
